==> jc-1.4.0.tar.gz: polyglot/visit/DataFlow__24Item.h <==
// public abstract class polyglot.visit.DataFlow$Item

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 146082755586f7f1 polyglot_visit_DataFlow__24Item

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_DataFlow__24Item_H_
#define _JC_polyglot_visit_DataFlow__24Item_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_polyglot_visit_DataFlow__24Item$sub_refs	_jc_polyglot_visit_DataFlow__24Item$sub_refs;
typedef struct _jc_polyglot_visit_DataFlow__24Item$sub_nonrefs	_jc_polyglot_visit_DataFlow__24Item$sub_nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24Item$refs	_jc_polyglot_visit_DataFlow__24Item$refs;
typedef struct _jc_polyglot_visit_DataFlow__24Item$nonrefs	_jc_polyglot_visit_DataFlow__24Item$nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24Item$object	_jc_polyglot_visit_DataFlow__24Item$object;

typedef const struct _jc_polyglot_visit_DataFlow__24Item$vmethods	_jc_polyglot_visit_DataFlow__24Item$vmethods;
typedef const struct _jc_polyglot_visit_DataFlow__24Item$vtable	_jc_polyglot_visit_DataFlow__24Item$vtable;
typedef const struct _jc_polyglot_visit_DataFlow__24Item$vtype	_jc_polyglot_visit_DataFlow__24Item$vtype;

// Constructors
extern void _jc_polyglot_visit_DataFlow__24Item$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *);

// Virtual methods
extern jboolean _jc_polyglot_visit_DataFlow__24Item$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_visit_DataFlow__24Item$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_DataFlow__24Item$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_DataFlow__24Item$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_polyglot_visit_DataFlow__24Item$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *);
};

// Vtable
struct _jc_polyglot_visit_DataFlow__24Item$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_DataFlow__24Item$vmethods	polyglot_visit_DataFlow__24Item;
};

// Vtype
struct _jc_polyglot_visit_DataFlow__24Item$vtype {
	_jc_type			type;
	_jc_polyglot_visit_DataFlow__24Item$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24Item$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24Item$refs {
    _jc_polyglot_visit_DataFlow__24Item$sub_refs	polyglot_visit_DataFlow__24Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24Item$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24Item$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_DataFlow__24Item$sub_nonrefs	polyglot_visit_DataFlow__24Item;
};

// Object instance structure
struct _jc_polyglot_visit_DataFlow__24Item$object {
	_jc_polyglot_visit_DataFlow__24Item$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_DataFlow__24Item$vtype	*vtype;
	_jc_polyglot_visit_DataFlow__24Item$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_DataFlow__24Item$vtype _jc_polyglot_visit_DataFlow__24Item$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_DataFlow__24Item, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_DataFlow__24Item$class_object;

#endif	/* _JC_polyglot_visit_DataFlow__24Item_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/DataFlow__24Item.h <==
// public abstract class polyglot.visit.DataFlow$Item

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 146082755586f7f1 polyglot_visit_DataFlow__24Item

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_DataFlow__24Item_H_
#define _JC_polyglot_visit_DataFlow__24Item_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_polyglot_visit_DataFlow__24Item$sub_refs	_jc_polyglot_visit_DataFlow__24Item$sub_refs;
typedef struct _jc_polyglot_visit_DataFlow__24Item$sub_nonrefs	_jc_polyglot_visit_DataFlow__24Item$sub_nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24Item$refs	_jc_polyglot_visit_DataFlow__24Item$refs;
typedef struct _jc_polyglot_visit_DataFlow__24Item$nonrefs	_jc_polyglot_visit_DataFlow__24Item$nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24Item$object	_jc_polyglot_visit_DataFlow__24Item$object;

typedef const struct _jc_polyglot_visit_DataFlow__24Item$vmethods	_jc_polyglot_visit_DataFlow__24Item$vmethods;
typedef const struct _jc_polyglot_visit_DataFlow__24Item$vtable	_jc_polyglot_visit_DataFlow__24Item$vtable;
typedef const struct _jc_polyglot_visit_DataFlow__24Item$vtype	_jc_polyglot_visit_DataFlow__24Item$vtype;

// Constructors
extern void _jc_polyglot_visit_DataFlow__24Item$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_visit_DataFlow__24Item$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_visit_DataFlow__24Item$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_DataFlow__24Item$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_DataFlow__24Item$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_polyglot_visit_DataFlow__24Item$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_visit_DataFlow__24Item$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_DataFlow__24Item$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_DataFlow__24Item$vmethods	polyglot_visit_DataFlow__24Item;
};

// Vtype
struct _jc_polyglot_visit_DataFlow__24Item$vtype {
	_jc_type			type;
	_jc_polyglot_visit_DataFlow__24Item$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24Item$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24Item$refs {
    _jc_polyglot_visit_DataFlow__24Item$sub_refs	polyglot_visit_DataFlow__24Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24Item$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24Item$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_DataFlow__24Item$sub_nonrefs	polyglot_visit_DataFlow__24Item;
};

// Object instance structure
struct _jc_polyglot_visit_DataFlow__24Item$object {
	_jc_polyglot_visit_DataFlow__24Item$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_DataFlow__24Item$vtype	*vtype;
	_jc_polyglot_visit_DataFlow__24Item$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_DataFlow__24Item$vtype _jc_polyglot_visit_DataFlow__24Item$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_DataFlow__24Item, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_DataFlow__24Item$class_object;

#endif	/* _JC_polyglot_visit_DataFlow__24Item_H_ */
